@@ -1,9 +1,7 @@
 /* 
  * ISO 8859-1 and UTF-8 to Morse code mappings 
  * This file is part of ebook2cw and may be used under the same terms (GPL)
- * (C) 2008-2017 Fabian Kurz, DJ1YFK 
- *
- * $Id$
+ * (C) 2008-2022 Fabian Kurz, DJ5CW
  *
  * Currently included: ISO 8859-1
  *                      - complete (all that can somehow be mapped)
@@ -173,7 +171,7 @@ const static char *iso8859[] = {
 	"..-..",	/* 'e */
 	".",		/* ^e */
 	".",		/* "e */
-	"..",		/* `i */
+	".---.",	/* `i */
 	"..",		/* 'i */
 	"..",		/* ^i */
 	"..",		/* "i */
@@ -265,7 +263,7 @@ const static char *utf8table[] = {
 	"..-..",	/* 'e */
 	".",		/* ^e */
 	".",		/* "e */
-	"..",		/* `i */
+	".---.",	/* `i */
 	"..",		/* 'i */
 	"..",		/* ^i */
 	"..",		/* "i */
@@ -410,7 +408,7 @@ const static char *utf8table[] = {
 	/* Greek Alphabet, small letters */       
 	".-", "-..." , "--.", "-..", ".", "--..", "....", 
 	"-.-.", "..", "-.-", ".-..", "--", "-.", "-..-", "---", 
-	".--.", ".-.", NULL, "...", "-", "-.--", "..-.", "----", 
+	".--.", ".-.", "...", "...", "-", "-.--", "..-.", "----", 
 	"--.-", ".--", NULL, NULL, NULL, NULL, NULL, NULL, 
 	NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 
 	NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 
@@ -488,8 +486,8 @@ const static char *utf8table[] = {
 	NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 
 	/* 1488-1514 Hebrew according to Wikipedia */
 	".-", "-...", "--.", "-..", "---", ".", "--..", "....", 
-	"..-", "..", NULL, "-.-", ".-..", NULL, "--", "-.", NULL,
-	"-.-.", ".---", NULL, ".--.", NULL, ".--", "--.-", ".-.", "...", 
+	"..-", "..", "-.-", "-.-", ".-..", "--", "--", "-.", "-.",
+	"-.-.", ".---", ".--.", ".--.", ".--", ".--", "--.-", ".-.", "...", 
 	"-", NULL, NULL, NULL, NULL, NULL, NULL, NULL, 
 	NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 
 	NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 
@@ -502,11 +500,11 @@ const static char *utf8table[] = {
 	 * 1569-1610
 	 */
 	".", NULL, NULL, NULL, NULL, NULL, 
-	".-", "-...", NULL, "-", "-.-.", 
+	".-", "-...", "-", "-", "-.-.", 
 	".---", "....", "---", "-..", "--..", ".-.", "---.", "...", 
 	"----", "-..-", "...-", "..-", "-.--", ".-.-", "--.", NULL, 
 	NULL, NULL, NULL, NULL, NULL, "..-.", "--.-", "-.-", 
-	".-..", "--", "-.", NULL, ".--", NULL, "..", NULL, 
+	".-..", "--", "-.", "..-..", ".--", NULL, "..", NULL, 
 	NULL, NULL, NULL, NULL, NULL, NULL, 
 	NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 
 	NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 
