@@ -1,7 +1,7 @@
 /* 
 ebook2cw - converts an ebook to Morse MP3/OGG-files
 
-Copyright (C) 2007 - 2021  Fabian Kurz, DJ1YFK
+Copyright (C) 2007 - 2023  Fabian Kurz, DJ5CW
 
 https://fkurz.net/ham/ebook2cw.html
 
@@ -57,6 +57,11 @@ source code looks properly indented with ts=4
 #include <errno.h>
 #endif
 
+#include <limits.h>			/* PATH_MAX */
+#ifndef PATH_MAX			/* Not defined e.g. on GNU/hurd */
+#define PATH_MAX 4096
+#endif
+
 #include "codetables.h"
 
 #ifndef VERSION
@@ -141,8 +146,8 @@ typedef struct {
 	unsigned char *mp3buffer;
 	/* Chapter splitting */
 	char chapterstr[80], 				/* split chapters by this string */
-		 chapterfilename[80],			/* Prefix, e.g. "Chapter-" */
-		 outfilename[256];				/* Full name of current outputfile */
+		 chapterfilename[PATH_MAX-8],	/* Prefix, e.g. "Chapter-" */
+		 outfilename[PATH_MAX];			/* Full name of current outputfile */
 	/* time based splitting, seconds */
 	int chaptertime;
 	/* word based splitting */
@@ -264,7 +269,7 @@ int main (int argc, char** argv) {
 		return EXIT_FAILURE;
 	}
 
-	printf(_("ebook2cw %s - (c) 2007 - 2021 by Fabian Kurz, DJ1YFK\n\n"), VERSION);
+	printf(_("ebook2cw %s - (c) 2007 - 2023 by Fabian Kurz, DJ5CW\n\n"), VERSION);
 
 	/* 
 	 * Find and read ebook2cw.conf 
@@ -523,9 +528,15 @@ cw.encoding = UTF8;
 
 
 		} /* word */
-
 	} /* eof */
 
+	/* If the file ends without newline or space, but directly with EOF after
+	 * the last word, this one is lost, so we need to add it... */
+	if (strlen(word) && word[0] != '|' && word[0] != '#') {
+		makeword(mapstring(word, &cw), &cw);
+		chw++; 
+	}
+
 /* CGI: Add some silence (500ms) to the end of the file */
 #ifdef CGI
 	add_silence(500, &cw);
@@ -925,11 +936,11 @@ void openfile (int chapter, CWP *cw) {
 
     /* If we have a chapter separator string, use format Chapter0001.mp3 */
 	if (strlen(cw->chapterstr) && cw->chapterstr[0] != '-') {
-		snprintf(cw->outfilename, 80, "%s%04d.%s",  cw->chapterfilename,
+		snprintf(cw->outfilename, PATH_MAX, "%s%04d.%s",  cw->chapterfilename,
 			chapter, (cw->encoder == MP3) ? "mp3" : "ogg");
 	}
 	else {  /* otherwise just Chapter.mp3 */
-		snprintf(cw->outfilename, 80, "%s.%s",  cw->chapterfilename,
+		snprintf(cw->outfilename, PATH_MAX, "%s.%s",  cw->chapterfilename,
 			(cw->encoder == MP3) ? "mp3" : "ogg");
 	}
 	printf(_("Starting %s\n"),  cw->outfilename);
@@ -985,6 +996,7 @@ void help (void) {
 	printf(_("         [-u] [-S ISO|UTF] [-n] [-e eff.wpm] [-W space]\n"));
 	printf(_("         [-N snr] [-B filter bandwidth] [-C filter center]\n"));
 	printf(_("         [-T 0..2] [-g filename] [-l words] [-d seconds]\n"));
+	printf(_("         [-O for OGG output format] \n"));
 	printf(_("         [infile]\n\n"));
 	printf(_("defaults: 25 WpM, 600Hz, RT=FT=50, s=11025Hz, b=16kbps,\n"));
 	printf(_("          c=\"CHAPTER\", o=\"Chapter\" infile = stdin\n"));
@@ -1287,7 +1299,7 @@ void setparameter (char i, char *value, CWP *cw) {
 				strncpy(cw->chapterstr, value, 78);
 				break;
 			case 'o':
-				strncpy(cw->chapterfilename, value, 78);
+				strncpy(cw->chapterfilename, value, PATH_MAX - 10);
 				break;
 			case 'a':
 				strncpy(cw->id3_author, value, 78);
